sievetools.Sieve
================

.. abjad-lineage:: abjad.tools.sievetools.Sieve.Sieve

.. autoclass:: abjad.tools.sievetools.Sieve.Sieve

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.sievetools.Sieve.Sieve.from_cycle_tokens
      ~abjad.tools.sievetools.Sieve.Sieve.get_boolean_train
      ~abjad.tools.sievetools.Sieve.Sieve.get_congruent_bases
      ~abjad.tools.sievetools.Sieve.Sieve.is_congruent_base
      ~abjad.tools.sievetools.Sieve.Sieve.logical_operator
      ~abjad.tools.sievetools.Sieve.Sieve.period
      ~abjad.tools.sievetools.Sieve.Sieve.rcs
      ~abjad.tools.sievetools.Sieve.Sieve.representative_boolean_train
      ~abjad.tools.sievetools.Sieve.Sieve.representative_congruent_bases
      ~abjad.tools.sievetools.Sieve.Sieve.__and__
      ~abjad.tools.sievetools.Sieve.Sieve.__eq__
      ~abjad.tools.sievetools.Sieve.Sieve.__format__
      ~abjad.tools.sievetools.Sieve.Sieve.__hash__
      ~abjad.tools.sievetools.Sieve.Sieve.__ne__
      ~abjad.tools.sievetools.Sieve.Sieve.__or__
      ~abjad.tools.sievetools.Sieve.Sieve.__repr__
      ~abjad.tools.sievetools.Sieve.Sieve.__xor__

Bases
-----

- :py:class:`sievetools.BaseResidueClass <abjad.tools.sievetools.BaseResidueClass.BaseResidueClass>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.sievetools.Sieve.Sieve.logical_operator
   :noindex:

.. autoattribute:: abjad.tools.sievetools.Sieve.Sieve.period
   :noindex:

.. autoattribute:: abjad.tools.sievetools.Sieve.Sieve.rcs
   :noindex:

.. autoattribute:: abjad.tools.sievetools.Sieve.Sieve.representative_boolean_train
   :noindex:

.. autoattribute:: abjad.tools.sievetools.Sieve.Sieve.representative_congruent_bases
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.get_boolean_train
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.get_congruent_bases
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.is_congruent_base
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.from_cycle_tokens
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__and__
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__eq__
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__format__
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__hash__
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__ne__
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__or__
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__repr__
   :noindex:

.. automethod:: abjad.tools.sievetools.Sieve.Sieve.__xor__
   :noindex:
